import * as ec2 from 'aws-cdk-lib/aws-ec2';
import { z } from 'zod';
/**
 * The infrastructure definition schema.
 */
export declare const InfrastructureDefinitionPropsSchema: z.ZodObject<{
    instanceType: z.ZodType<ec2.InstanceType, z.ZodTypeDef, ec2.InstanceType>;
    maxMemory: z.ZodNumber;
    gpus: z.ZodDefault<z.ZodNumber>;
}, "strip", z.ZodTypeAny, {
    instanceType: ec2.InstanceType;
    maxMemory: number;
    gpus: number;
}, {
    instanceType: ec2.InstanceType;
    maxMemory: number;
    gpus?: number | undefined;
}>;
export type InfrastructureDefinitionProps = z.infer<typeof InfrastructureDefinitionPropsSchema>;
/**
 * The infrastructure definition builder.
 */
export declare class InfrastructureDefinitionBuilder {
    private props;
    /**
     * Sets the instance type to use.
     * @param instanceType the instance type to use.
     * @returns the builder instance.
     */
    withInstanceType(instanceType: ec2.InstanceType): this;
    /**
     * Sets the maximum memory to use.
     * @param maxMemory the maximum memory to use.
     * @returns the builder instance.
     */
    withMaxMemory(maxMemory: number): this;
    /**
     * Sets the number of GPUs to use.
     * @param gpus the number of GPUs to use.
     * @returns the builder instance.
     */
    withGpus(gpus: number): this;
    /**
     * Builds the infrastructure definition.
     * @returns the infrastructure definition.
     */
    build(): InfrastructureDefinition;
}
/**
 * Describes the infrastructure to use for running
 * an ollama model.
 */
export declare class InfrastructureDefinition {
    props: InfrastructureDefinitionProps;
    /**
     * The `InfrastructureDefinition` builder.
     */
    static readonly Builder: typeof InfrastructureDefinitionBuilder;
    /**
     * Creates a new instance of the `InfrastructureDefinition` class.
     * @param props the infrastructure definition properties.
     */
    constructor(props: InfrastructureDefinitionProps);
    /**
     * @returns the instance type to use.
     */
    instanceType(): ec2.InstanceType;
    /**
     * @returns the maximum memory to use.
     */
    maxMemory(): number;
    /**
     * @returns the number of GPUs to use.
     */
    gpus(): number;
    /**
     * Creates a new instance of the `InfrastructureDefinition` class.
     * @param props the infrastructure definition properties.
     * @returns a new instance of the `InfrastructureDefinition` class.
     */
    static from(props: any): InfrastructureDefinition;
    /**
     * @returns the JSON representation of the
     * infrastructure definition.
     */
    toJSON(): {
        instanceType: ec2.InstanceType;
        maxMemory: number;
        gpus: number;
    };
}
